@@ -1,15 +1,16 @@
 package DateTime::Calendar::Julian;
 
 use strict;
-use warnings;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = '0.106_04';
+$VERSION = '0.03';
 
 use DateTime 0.08;
 @ISA = 'DateTime';
 
+use Params::Validate qw( validate SCALAR BOOLEAN OBJECT );
+
 sub _floor {
     my $x  = shift;
     my $ix = int $x;
@@ -27,14 +28,14 @@ my @start_of_month = (0, 31, 61, 92, 122, 153, 184, 214, 245, 275, 306, 337);
 
 # This is the difference between Julian and Gregorian calendar:
 sub _is_leap_year {
-    my (undef, $year) = @_;	# Invocant unused
+    my ($self, $year) = @_;
 
     return ($year % 4 == 0);
 }
 
 # Algorithms from http://home.capecod.net/~pbaum/date/date0.htm
-sub _ymd2rd {	## no critic (ProhibitUnusedPrivateSubroutines)
-    my (undef, $y, $m, $d) = @_;	# Invocant unused
+sub _ymd2rd {
+    my ($self, $y, $m, $d) = @_;
 
     my $adj = _floor( ($m-3)/12 );
     $m -= 12 * $adj;
@@ -44,44 +45,25 @@ sub _ymd2rd {	## no critic (ProhibitUnusedPrivateSubroutines)
     return $rd;
 }
 
-{
-    my @QuarterStart = my @LeapYearQuarterStart = ( 0, 90, 181, 273 );
-    $LeapYearQuarterStart[$_] += 1 for 1 .. 3;
+sub _rd2ymd {
+    my ($self, $rd, $extra) = @_;
 
-    sub _rd2ymd {	## no critic (ProhibitUnusedPrivateSubroutines)
-	my ($class, $rd, $extra) = @_;
-
-	my $z = $rd + 308;
-	my $y = _floor(($z*100-25)/36525);
-	my $c = $z - _floor(365.25*$y);
-	my $m = int((5*$c + 456)/153);
-	my $d = $c - $start_of_month[$m-3];
-	if ($m > 12) {
-	    $m -= 12;
-	    $y++;
-	}
-
-	if ($extra) {
-	    # day_of_week, day_of_year
-	    my $doy = ($c + 31 + 28 - 1)%365 + 1 +
-			  ($class->_is_leap_year($y) && $m > 2);
-	    my $dow = (($rd + 6)%7) + 1;
-
-	    # quarter -- see DateTime::PP->rd2ymd()
-	    my $quarter = int( ( 1 / 3.1 ) * $m ) + 1;
-
-	    my $doq = $doy - ( $class->_is_leap_year( $y ) ?
-		$LeapYearQuarterStart[ $quarter - 1 ] :
-		$QuarterStart[ $quarter - 1 ] );
-
-	    return $y, $m, $d, $dow, $doy, $quarter, $doq;
-	}
-	return $y, $m, $d;
+    my $z = $rd + 308;
+    my $y = _floor(($z*100-25)/36525);
+    my $doy = $z - _floor(365.25*$y);
+    my $m = int((5*$doy + 456)/153);
+    my $d = $doy - $start_of_month[$m-3];
+    if ($m > 12) {
+        $m -= 12;
+        $y++;
     }
-}
 
-sub calendar_name {
-    return 'Julian';
+    if ($extra) {
+        # day_of_week, day_of_year
+        my $dow = (($rd + 6)%7) + 1;
+        return $y, $m, $d, $dow, $doy;
+    }
+    return $y, $m, $d;
 }
 
 sub epoch {
@@ -107,15 +89,6 @@ sub gregorian_deviation {
     return _floor($year/100)-_floor($year/400)-2;
 }
 
-# NOTE: Do NOT just default the separator to 'J' and delegate to SUPER.
-# This will not work before DateTime 1.43 because before that the
-# datetime() method did not have an argument.
-sub datetime {
-    my ( $self, $sep ) = @_;
-    $sep = 'J' unless defined $sep;
-    return join $sep, $self->ymd( '-' ), $self->hms( ':' );
-}
-
 1;
 
 __END__
@@ -136,12 +109,10 @@ DateTime::Calendar::Julian - Dates in the Julian calendar
   # convert Julian->Gregorian...
 
   $dtgreg = DateTime->from_object( object => $dt );
-  print $dtgreg->datetime;  # prints '0964-10-21T00:00:00'
 
   # ... and back again
 
   $dtjul = DateTime::Calendar::Julian->from_object( object => $dtgreg );
-  print $dtjul->datetime;  # prints '0964-10-16J00:00:00'
 
 =head1 DESCRIPTION
 
@@ -152,43 +123,17 @@ methods.
 =head1 METHODS
 
 This module implements one additional method besides the ones from
-DateTime, and changes the output of one other method.
+DateTime.
 
 =over 4
 
-=item * calendar_name
-
-Returns C<'Julian'>.
-
 =item * gregorian_deviation
 
 Returns the difference in days between the Gregorian and the Julian
 calendar.
 
-=item * datetime
-
-  print $dt->datetime( $sep ), "\n";
-
-This method is equivalent to
-
-  join $sep, $dt->ymd( '-' ), $dt->hms( ':' );
-
-The C<$sep> argument defaults to C<'J'>.
-
-B<Caveat:> the optional argument was added to this method in version
-1.02, to belatedly track a change made in L<DateTime|DateTime> version
-1.43 released 2017-05-29. Fixing this restores the original
-stringification behavior of this class, which was to return an ISO-8601
-string unless a formatter was set. Before this change, the
-stringification separated date and time with either a C<'T'> or a
-C<'J'>, depending on which version of L<DateTime|DateTime> was
-installed.
-
 =back
 
-B<Note> that as of version C<0.106_01>, methods related to quarters
-should work.
-
 =head1 BACKGROUND
 
 The Julian calendar was introduced by Julius Caesar in 46BC.  It
@@ -212,43 +157,25 @@ year 1BC (there was no year 0AD!), -1 the year 2BC, etc.
 
 =head1 SUPPORT
 
-Support for this module is provided via the F<datetime@perl.org> email
-list. See L<https://lists.perl.org/> for more details.
-
-Please report bugs to
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-Calendar-Julian>,
-L<https://github.com/trwyant/perl-DateTime-Calendar-Julian/issues>, or
-in electronic mail to F<wyant@cpan.org>.
+Support for this module is provided via the datetime@perl.org email
+list. See http://lists.perl.org/ for more details.
 
 =head1 AUTHOR
 
 Eugene van der Pijll <pijll@gmx.net>
 
-Thomas R. Wyant, III F<wyant at cpan dot org>
+=head1 COPYRIGHT
 
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (c) 2003 Eugene van der Pijll.  All rights reserved.
-
-Copyright (C) 2018-2022 Thomas R. Wyant, III
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-This program is distributed in the hope that it will be useful, but
-without any warranty; without even the implied warranty of
-merchantability or fitness for a particular purpose.
+Copyright (c) 2003 Eugene van der Pijll.  All rights reserved.  This
+program is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<DateTime|DateTime>
-
-L<DateTime::Calendar::Christian|DateTime::Calendar::Christian>
+L<DateTime>
 
 datetime@perl.org mailing list
 
-L<http://datetime.perl.org/>
+http://datetime.perl.org/
 
 =cut
-
-# ex: set textwidth=72 :
